@@ -403,6 +403,10 @@ bool DigitDoc::openDocument(const QString &filename)
   str >> (Q_INT32 &) m_exportSettings.layout;
   str >> (Q_INT32 &) m_exportSettings.pointsSelection;
   str >> (Q_INT32 &) m_exportSettings.header;
+  if (versionNumber >= 5.2) {
+    str >> m_exportSettings.xLabel;
+    str >> m_exportSettings.thetaLabel;
+  }
 
   str >> (Q_INT32 &) m_gridRemovalSettings.removeThinLines;
   str >> (double &) m_gridRemovalSettings.thinThickness;
@@ -420,7 +424,18 @@ bool DigitDoc::openDocument(const QString &filename)
   str >> (double &) m_gridRemovalSettings.gridMesh.stopY;
   str >> (double &) m_gridRemovalSettings.gridDistance;
   str >> (Q_INT32 &) m_gridRemovalSettings.removeColor;
-  str >> m_gridRemovalSettings.color;
+
+  if (versionNumber >= 5) 
+  {
+     str >> m_gridRemovalSettings.color;
+  }
+  else
+  {
+     Q_UINT32 p;
+     str >> p;
+     m_gridRemovalSettings.color.setRgb( p );
+  }
+
   str >> (Q_INT32 &) m_gridRemovalSettings.foregroundThresholdLow;
   str >> (Q_INT32 &) m_gridRemovalSettings.foregroundThresholdHigh;
   str >> (double &) m_gridRemovalSettings.gapSeparation;
@@ -534,6 +549,8 @@ bool DigitDoc::saveDocument(const QString &filename)
   str << (Q_INT32 &) m_exportSettings.layout;
   str << (Q_INT32 &) m_exportSettings.pointsSelection;
   str << (Q_INT32 &) m_exportSettings.header;
+  str << m_exportSettings.xLabel;
+  str << m_exportSettings.thetaLabel;
 
   str << (Q_INT32 &) m_gridRemovalSettings.removeThinLines;
   str << (double &) m_gridRemovalSettings.thinThickness;
@@ -612,7 +629,7 @@ bool DigitDoc::exportDocument(const QString &filename)
 {
   QFile file(filename);
 
-  if (!file.open(QIODevice::WriteOnly | QIODevice::Text))
+  if (!file.open(QIODevice::WriteOnly | QIODevice::Truncate | QIODevice::Text))
     return false;
 
   Q3TextStream str(&file);
@@ -873,7 +890,7 @@ void DigitDoc::trackCursor(const QPoint &p)
         (DefaultSettings::instance().getPowerMostSigMin() > powerMostSigX))
       {
         ASSERT_ENGAUGE(m_canvas.width() > 1);
-        precisionX = (int) (1 + log10(m_canvas.width()));
+        precisionX = (int) (1 + log10((double) m_canvas.width()));
         roundedX = xTheta;
         roundedXRes = xThetaRes;
         xFormat = "%.*e"; // use e since g does not have trailing zeros, causing flicker during mouse moves
@@ -882,7 +899,7 @@ void DigitDoc::trackCursor(const QPoint &p)
         (DefaultSettings::instance().getPowerMostSigMin() > powerMostSigY))
       {
         ASSERT_ENGAUGE(m_canvas.height() > 1);
-        precisionY = (int) (1 + log10(m_canvas.height()));
+        precisionY = (int) (1 + log10((double) m_canvas.height()));
         roundedY = yR;
         roundedYRes = yRRes;
         yFormat = "%.*e"; // use e since g does not have trailing zeros, causing flicker during mouse moves
@@ -1389,7 +1406,7 @@ void DigitDoc::print()
 
 QString DigitDoc::filterImport()
 {
-  QString filter(tr("Images (*.bmp *.gif *.jpg *.png *.pnm *.pbm *.xpm);;All Files (*.*)"));
+  QString filter(tr("Images (*.bmp *.gif *.jpg *.jpeg *.png *.pnm *.pbm *.xpm);;All Files (*.*)"));
 
   if (cmdOnlyBmp)
     filter = tr("Images (*.bmp);;All Files (*.*)");
@@ -1620,7 +1637,7 @@ void DigitDoc::highlightCandidateMatchPoint(const QPoint &p)
       PointMatch pointMatch;
       pointMatch.isolateSampleMatchPoint(&m_samplePointPixels,
         m_processedImage, m_pointMatchSettings,
-        p.x(), p.y(), p.x(), p.y());
+        p.x(), p.y());
       addSampleMatchPointToViews();
 
       QApplication::restoreOverrideCursor();
